@@ -122,10 +122,6 @@ static constexpr double LENGTH_EPS    =  1e-6;
 static constexpr double VERY_POSITIVE =  1e10;
 static constexpr double VERY_NEGATIVE = -1e10;
 
-inline double Random(double vmax) {
-    return (vmax*rand()) / RAND_MAX;
-}
-
 #include "platform/platform.h"
 #include "platform/gui.h"
 #include "resource.h"
@@ -272,7 +268,8 @@ public:
     void EvalJacobian();
 
     void WriteEquationsExceptFor(hConstraint hc, Group *g);
-    void FindWhichToRemoveToFixJacobian(Group *g, List<hConstraint> *bad, bool forceDofCheck);
+    void FindWhichToRemoveToFixJacobian(Group *g, List<hConstraint> *bad,
+                                        bool forceDofCheck);
     void SolveBySubstitution();
 
     bool IsDragged(hParam p);
@@ -343,6 +340,7 @@ public:
     virtual void Bezier(SBezier *sb) = 0;
     virtual void Triangle(STriangle *tr) = 0;
     virtual bool OutputConstraints(IdList<Constraint,hConstraint> *) { return false; }
+    virtual void Background(RgbaColor color) = 0;
     virtual void StartFile() = 0;
     virtual void FinishAndCloseFile() = 0;
     virtual bool HasCanvasSize() const = 0;
@@ -367,6 +365,7 @@ public:
                     bool filled, RgbaColor fillRgb, hStyle hs) override;
     void Triangle(STriangle *tr) override;
     void Bezier(SBezier *sb) override;
+    void Background(RgbaColor color) override;
     void StartFile() override;
     void FinishAndCloseFile() override;
     bool HasCanvasSize() const override { return false; }
@@ -384,6 +383,7 @@ public:
                     bool filled, RgbaColor fillRgb, hStyle hs) override;
     void Triangle(STriangle *tr) override;
     void Bezier(SBezier *sb) override;
+    void Background(RgbaColor color) override;
     void StartFile() override;
     void FinishAndCloseFile() override;
     bool HasCanvasSize() const override { return true; }
@@ -402,6 +402,7 @@ public:
                     bool filled, RgbaColor fillRgb, hStyle hs) override;
     void Triangle(STriangle *tr) override;
     void Bezier(SBezier *sb) override;
+    void Background(RgbaColor color) override;
     void StartFile() override;
     void FinishAndCloseFile() override;
     bool HasCanvasSize() const override { return true; }
@@ -418,6 +419,7 @@ public:
                     bool filled, RgbaColor fillRgb, hStyle hs) override;
     void Triangle(STriangle *tr) override;
     void Bezier(SBezier *sb) override;
+    void Background(RgbaColor color) override;
     void StartFile() override;
     void FinishAndCloseFile() override;
     bool HasCanvasSize() const override { return true; }
@@ -432,6 +434,7 @@ public:
                     bool filled, RgbaColor fillRgb, hStyle hs) override;
     void Triangle(STriangle *tr) override;
     void Bezier(SBezier *sb) override;
+    void Background(RgbaColor color) override;
     void StartFile() override;
     void FinishAndCloseFile() override;
     bool HasCanvasSize() const override { return false; }
@@ -445,6 +448,7 @@ class Step2dFileWriter : public VectorFileWriter {
                     bool filled, RgbaColor fillRgb, hStyle hs) override;
     void Triangle(STriangle *tr) override;
     void Bezier(SBezier *sb) override;
+    void Background(RgbaColor color) override;
     void StartFile() override;
     void FinishAndCloseFile() override;
     bool HasCanvasSize() const override { return false; }
@@ -459,6 +463,7 @@ public:
                     bool filled, RgbaColor fillRgb, hStyle hs) override;
     void Triangle(STriangle *tr) override;
     void Bezier(SBezier *sb) override;
+    void Background(RgbaColor color) override;
     void StartFile() override;
     void FinishAndCloseFile() override;
     bool HasCanvasSize() const override { return false; }
@@ -558,11 +563,13 @@ public:
     int      maxSegments;
     double   exportChordTol;
     int      exportMaxSegments;
+    int      timeoutRedundantConstr; //milliseconds
     double   cameraTangent;
     double   gridSpacing;
     double   exportScale;
     double   exportOffset;
     bool     fixExportColors;
+    bool     exportBackgroundColor;
     bool     drawBackFaces;
     bool     showContourAreas;
     bool     checkClosedContour;
@@ -672,6 +679,8 @@ public:
     void UpgradeLegacyData();
     bool LoadEntitiesFromFile(const Platform::Path &filename, EntityList *le,
                               SMesh *m, SShell *sh);
+    bool LoadEntitiesFromSlvs(const Platform::Path &filename, EntityList *le,
+                              SMesh *m, SShell *sh);
     bool ReloadAllLinked(const Platform::Path &filename, bool canCancel = false);
     // And the various export options
     void ExportAsPngTo(const Platform::Path &filename);
@@ -803,6 +812,7 @@ public:
 
 void ImportDxf(const Platform::Path &file);
 void ImportDwg(const Platform::Path &file);
+bool LinkIDF(const Platform::Path &filename, EntityList *le, SMesh *m, SShell *sh);
 
 extern SolveSpaceUI SS;
 extern Sketch SK;
